
#ifndef _C11_ev517_
#define _C11_ev517_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1157_10876(EIF_REFERENCE);
extern EIF_REFERENCE F1157_10877(EIF_REFERENCE);
extern void EIF_Minit517(void);
extern char *(*R8711[])();
extern char *(*R8712[])();

#ifdef __cplusplus
}
#endif

#endif
